@@ -13,7 +13,11 @@ class LanzouDirectory(BaseTable):
                            Column('gmt_modified', TIMESTAMP(True), server_default=func.now()),
                            Column('isfile', BIGINT, comment='是否文件', default='1'),
                            Column('name', String(100), comment='名称', default=''),
+                           Column('desc', String(500), comment='描述', default='0'),
                            Column('path', String(500), comment='路径', default=''),
+                           Column('downs', BIGINT, comment='下载次数', default='0'),
+                           Column('url', String(100), comment='分享链接', default='0'),
+                           Column('pwd', String(50), comment='提取码', default='0'),
                            )
         self.create()
         self.drive = LanZouDrive()
@@ -28,11 +32,19 @@ class LanzouDirectory(BaseTable):
 
     def _scan_all_file(self, fid, path):
         for _dir in self.drive.get_dir_list(fid):
+            _path = f'{path}/{_dir.name}'
+            if self.file_exist(_path):
+                continue
+            share = self.drive.get_share_info(fid=_dir.id, is_file=False)
             data = {
                 "fid": _dir.id,
                 "name": _dir.name,
-                "path": f'{path}/{_dir.name}',
-                "isfile": 0
+                "path": _path,
+                "isfile": 0,
+                "downs": _dir.downs,
+                "desc": share.desc,
+                "url": share.url,
+                "pwd": share.pwd
             }
             self.insert(values=data)
             if _dir.name.endswith(".tar"):
@@ -40,11 +52,19 @@ class LanzouDirectory(BaseTable):
             self._scan_all_file(fid=data['fid'], path=data['path'])
 
         for _file in self.drive.get_file_list(fid):
+            _path = f'{path}/{_file.name}'
+            if self.file_exist(_path):
+                continue
+            share = self.drive.get_share_info(fid=_dir.id, is_file=True)
             data = {
                 "fid": _file.id,
                 "name": _file.name,
-                "path": f'{path}/{_file.name}',
-                "isfile": 1
+                "path": _path,
+                "isfile": 1,
+                "downs": _dir.downs,
+                "desc": share.desc,
+                "url": share.url,
+                "pwd": share.pwd
             }
             self.insert(values=data)
 
